Module syscalls

Module syscalls 

Enums

SysError
Syscall errors

Constants

SYS_FIND_CELL_BY_OUT_POINT
System call number for finding a cell by OutPoint
SYS_FIND_CELL_DATA_BY_OUT_POINT
System call number for finding cell data by OutPoint
SYS_FIND_OUT_POINT_BY_TYPE
System call number for finding an OutPoint by type script

Functions

find_cell_by_out_point
Find a cell by its OutPoint
find_cell_data_by_out_point
Find cell data by OutPoint
find_out_point_by_type
Find an OutPoint by searching for a specific type script
syscall
vm_version